package JavaCode;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.util.StringTokenizer;

// import org.ensembl.driver.CoreDriverFactory;
// import org.ensembl.driver.TranscriptAdaptor;
// import org.ensembl.variation.driver.VariationDriverFactory;

/*
	SLIDER: Local Short Reads DNA Sequence Alignment
	Beta Release; Ver 0.1, 22th Mar. 2008
	By: Nawar Malhis
	Canada's Michael Smith Genome Sciences Centre
 */

public class Parameters {
	// public static TranscriptAdaptor ta;
	static		 boolean multi       = true;       // for multi match output
    static final int     MMBRK       = 5;       // max number of mm
	static		 boolean skipValue;
	static       int     skipCycles  = 0;
	static final int     petHistSize = 1000;
	static       int     mapAdjust   = 0;
	static       float   snpPer = (float) 0.85;
	static       float   snpPerW = (float) 0.85;
	static       float   snpPerWWk = (float) 0.7;
	static       int     snpMinCover   = 2;
	static       int     snpMinCoverWk = 2;
	// static       int     minCoverWk    = 2;
	// static       int     minCover      = 2;
	// static       int     snpTotalCover = 5;
	static       float   snpMinWeight  = (float) 2;
	static       int     CNVcomp = 1000;
	static       int     rangeScoreDist = 101;
	static final int     SET = 0;
	static final int     PET = 1;
	static final int     F   = 0;
	static final int     R   = 1;
	static       int     pQuality = 1; // 1/5 for 40/30;
	static       boolean snpRef   = false; 
	static       boolean contDB   = false;
    static       int     mmHistSize = 100;
	// static       int     DATATYPE;
	static final int     numberOfTimePoints = 10;
	static long[]        fStart        = new long[numberOfTimePoints];
	static int           fSize         = 50000000; // 50.0M record
	static int           fSortSize     =  6000000; //  6.0M record
	static       float   seqSegNucP    = (float) 0.998; // used by Seq to determine UD bases 
	static final int     maxUDN        = 11;            // used by Seq to determine if a sequence will have more than one copy 
	
	static float         cutWeight;    // is used for filtering to ol1, = minWeight * oMxSize
	static       float   minWeight     = (float) 0.002; // used in CreateSequences and in filtering ol1
	// static       float   maxWeight     = (float) 0.97;
	static final int     maxMu         = 127;           // used in CreateSequences
	// static final int     numOf_Reads    = 10000000;
	static final int     maxId         = 1000000000;  // 1G
    static public int    dbOligoSize   = 62; // max oligo size
    static        int    mapHistSize   = 30;
    static       int     extra0        = 2; // for mapping score oy u1
    // 	PET
    static final int     maxIdPet      = 50;
    static       int     petSpam       = 150;
    static final int     maxPetSpam    = 350;
	//* Load
	static public int    oMxSize      = 0;
	// static public int    oMnSize      = 0;
	// --- Dataset
	static public int    ETag       = SET;
	static public String DATASET    = "";
	static public String DATABASE   = ""; 
	// static public String NOISE_DATABASE   = "NOISE"; 
	// --- input reference sequences
	static public String ch_name1   = "";
	static public String[] SEQ_VAR  = {};
	static public String ch_name2   = "";
	static public String   outFile; // it is just "s"
	// --- paths
	static public String   pathDB;
	static public String   pathPRB;  
	static public String   pathData;
	static public String   pathOut; 
	static public String   pathRefSeq;
	static public String   pathConRefSeq; // = "/projects/nmalhis/clean";
	static public String   pathMulti;
	static public String   pathParallel;
	static public int      numberOfMultiSets = 1;

	static public String host = "ensembl01";
    static public int    port = 3306;
    static public String dbname   = "caenorhabditis_elegans_core_49_180a";
    static public String SNPvardb = "caenorhabditis_elegans_variation_49_180a";
    static public String user     = "ensembl";
    static public String password = "ensembl";

	public static void main(String[] args) throws Exception {
		if (args.length < 1) {
			System.err.println("delete what?");
		} else {
			delete(args[0]);
		}
	}

	
	static void read(String fl) throws Exception {
		String etag;
		String stk;
		String line;
		StringTokenizer st;
		
		System.err.println("\n\n\tSlider - Maximum use of probability information for alignment of short sequence reads and SNP detection");
		System.err.println("\tBeta Release; Ver 0.6\t 2nd July. 2008");
		System.err.println("\tBy: Nawar Malhis");
		System.err.println("\tCanada's Michael Smith Genome Sciences Centre, Vancouver\n\n");

		try {
			BufferedReader reader = new BufferedReader(new FileReader(fl));
			
			line = reader.readLine();
			st = new StringTokenizer(line);
			if (!st.hasMoreTokens()) {
				System.err.println(line);
				return;
			}
			stk = st.nextToken();
			stk = st.nextToken();
			oMxSize = new Integer(stk).intValue();
			
			line = reader.readLine();
			st = new StringTokenizer(line);
			if (!st.hasMoreTokens()) {
				System.err.println(line);
				return;
			}
			stk = st.nextToken();
			stk = st.nextToken();
			skipCycles = new Integer(stk).intValue();

			line = reader.readLine();
			st = new StringTokenizer(line);
			if (!st.hasMoreTokens()) {
				System.err.println(line);
				return;
			}
			stk = st.nextToken();
			etag = st.nextToken();
			if(etag.compareTo("SET") == 0) {
				ETag = SET;
			} else if(etag.compareTo("PET") == 0) {
				ETag = PET;
			} 

			line = reader.readLine();
			st = new StringTokenizer(line);
			if (!st.hasMoreTokens()) {
				System.err.println(line);
				return;
			}
			stk = st.nextToken();
			DATASET = st.nextToken();
			
			line = reader.readLine();
			st = new StringTokenizer(line);
			if (!st.hasMoreTokens()) {
				return;
			}
			stk = st.nextToken();
			DATABASE = st.nextToken();

			line = reader.readLine();
			st = new StringTokenizer(line);
			if (!st.hasMoreTokens()) {
				return;
			}
			stk = st.nextToken();
			pathRefSeq = st.nextToken();

			line = reader.readLine();
			st = new StringTokenizer(line);
			if (!st.hasMoreTokens()) {
				return;
			}
			stk = st.nextToken();
			pathDB = st.nextToken();

			line = reader.readLine();
			st = new StringTokenizer(line);
			if (!st.hasMoreTokens()) {
				return;
			}
			stk = st.nextToken();
			pathPRB = st.nextToken();

			line = reader.readLine();
			st = new StringTokenizer(line);
			if (!st.hasMoreTokens()) {
				return;
			}
			stk = st.nextToken();
			pathData = st.nextToken();

			line = reader.readLine();
			st = new StringTokenizer(line);
			if (!st.hasMoreTokens()) {
				return;
			}
			stk = st.nextToken();
			if (st.hasMoreTokens()) {
				ch_name1 = st.nextToken();
			}

			line = reader.readLine();
			st = new StringTokenizer(line);
			if (!st.hasMoreTokens()) {
				return;
			}
			int sz = st.countTokens() - 1;
			if (!st.hasMoreTokens()) {
				return;
			}
			stk = st.nextToken();
			SEQ_VAR = new String[sz];
			for (int i = 0; i < sz; i++) { // countTokens() 
				SEQ_VAR[i] = st.nextToken();
		    }

			line = reader.readLine();
			st = new StringTokenizer(line);
			if (!st.hasMoreTokens()) {
				return;
			}
			stk = st.nextToken();
			if (st.hasMoreTokens()) {
				ch_name2 = st.nextToken();
			} else {
				ch_name2 = "";
			}
			
			line = reader.readLine();
			st = new StringTokenizer(line);
			if (!st.hasMoreTokens()) {
				return;
			}
			stk = st.nextToken();
			if (st.hasMoreTokens()) {
				pathMulti = st.nextToken();
			} else {
				pathMulti = "";
			}

			line = reader.readLine();
			st = new StringTokenizer(line);
			if (!st.hasMoreTokens()) {
				return;
			}
			stk = st.nextToken();
			if (st.hasMoreTokens()) {
				pathParallel = st.nextToken();
			} else {
				pathParallel = "";
			}

			// System.out.println("pathMulti:\t" + pathMulti); // ch_name2 pathMulti pathParallel
			
			reader.close();
			
			
			pathPRB    += DATASET;  
			pathData   += DATASET;  
			pathConRefSeq = pathData + "contamination/"; 
			pathOut    = pathData + "Results/"; 
			outFile    = "s";
			// System.err.println("------------------------------->" + pathData);
		} catch (Exception er) {
			System.err.println("Parameters input file not found:\n\tinput/" + fl);
		}
		cutWeight = minWeight * oMxSize;
	}
	
	static void printTime(int tPoint)  throws Exception {
		if (tPoint < numberOfTimePoints && tPoint >= 0) {
			long fSec = (System.currentTimeMillis()-fStart[tPoint])/1000;
			long fMin = fSec / 60;
			long fHur = fSec / 3600;
			fSec = fSec - (fMin * 60);
			fMin = fMin - (fHur * 60);
			System.err.print("\t" + fHur + ":" + fMin + ":" + fSec);
			fStart[tPoint] = System.currentTimeMillis();
		}
	}

	static void resetTime() {
		fStart[0] = System.currentTimeMillis();
		for (int i = 1; i < numberOfTimePoints; i++) {
			fStart[i] = fStart[0];
		}

	}

    static public float trim(double d) {
    	return ((float) ((int) (d * 100))) / 100;
    }

	static void delete(String file) {
		System.err.println("Deleting:\t" + file);
		File fl = new File(file);
        File[] files = fl.listFiles();
        for(int i=0; i<files.length; i++) {
            if(files[i].isDirectory()) {
            	delete(files[i].toString());
            }
           	files[i].delete();
        }
	}

	static public void displayMemory(String text) {
		System.out.print  (text);
		System.out.print  ("\tTotal Memory:\t" + Runtime.getRuntime().totalMemory() + "\tFree Memory:\t" + Runtime.getRuntime().freeMemory());
		System.out.println("\tUsed Memory:\t" + (Runtime.getRuntime().totalMemory() - Runtime.getRuntime().freeMemory()));
	}
}

